==> dbfm-5.x-3.3.tar.gz: dbfm/js/upload.js <==
//this is some simple JS / JQuery code that sets a listener on the file selector. When the user has chosen a 
//file the listener calls a function which makes an AJAX call back to the server to detect duplicate filenames. 
//If a duplicate is found the AJAX call returns True to indicate that we need to display an additional prompt 
//to the user - we cause the prompt to appear for a duplicate. If the user re-selects the AJAX call may return false
//in which case we re-hide the prompt


//the getModUrl() is used by contrib modules for custom ajax and is in drupal.js 
function ajaxUrl() {
  var path = getBaseUrl() + "/?q=";
  return path += (typeof getModUrl == "undefined") ? "dbfm_js" : getModUrl();
}

$(document).ready(function() {
  //this code becomes effective as soon as the document is fully loaded
  //looks at the lostfocus events - I should probably just test the single lost focus
  //event for the fname box? I'm still not sure about lost focus!
  //note that if a duplicate is found a hidden form variable is set

  //changed the code to trigger on change - gives a far more immediate effect

  $('#dupradio').hide();
  $('#dupvmes').hide();
  $('#vertext').hide();
  $('#duphidden').hide();
  //this only works once the form has focus
  document.onkeypress=function(e){
    var e = window.event || e;
    if (e.keyCode == 27 || e.which == 27){
      parent.dbFM.popUp = true;   //try to fill a variable to prevent a directory fetch
      parent.GB_hide();
    }
  }

  var cssObj = {
    backgroundColor: "#ddd",
    color: "rgb(0,40,244)"
  }
  $('#dupradio').css(cssObj);
  $('#dupvmes').css(cssObj);

  $('form :input').change(function() {
    if (this.id == "edit-fname") {
      if (this.value != "") {
        //we need to make an ajax call to the server passing the selected filename
        $.ajax({
          type: "POST",
          url: ajaxUrl(),
          data: "action=fnamechk&fname=" + this.value,
          success: function(msg){
            //check the return values then hide or re-display the choice prompt
            //I THINK we're missing the drupal call??
            var result = Drupal.parseJson(msg);
            if (result.status == false) {
              //hide the prompt for versions / overwrite
              $('#dupradio').hide();
              $('#vertext').hide();
              $('#dupvmes').hide();
              $('#edit-duphidden').val('0');
            }
            else {
              //display the appropriate prompt control
              if (result.data == 'Version found') {
                $('#vertext').show();
                $('#dupvmes').show();
                $('#dupradio').hide();
                $('#edit-duphidden').val('2');
              }
              else {
                $('#vertext').show();
                $('#dupradio').show();
                $('#dupvmes').hide();
                $('#edit-duphidden').val('1');
             }
            }
          }
        });  //end of AJAX call
      }
    }
  });  //end of lostfocus trap
});  //end of ready code

==> dbfm-5.x-4.0.tar.gz: dbfm/js/upload.js <==
//this is some simple JS / JQuery code that sets a listener on the file selector. When the user has chosen a 
//file the listener calls a function which makes an AJAX call back to the server to detect duplicate filenames. 
//If a duplicate is found the AJAX call returns True to indicate that we need to display an additional prompt 
//to the user - we cause the prompt to appear for a duplicate. If the user re-selects the AJAX call may return false
//in which case we re-hide the prompt


//the getModUrl() is used by contrib modules for custom ajax and is in drupal.js 
function ajaxUrl() {
  var path = getBaseUrl() + "/?q=";
  return path += (typeof getModUrl == "undefined") ? "dbfm_js" : getModUrl();
}

$(document).ready(function() {
  //this code becomes effective as soon as the document is fully loaded
  //looks at the lostfocus events - I should probably just test the single lost focus
  //event for the fname box? I'm still not sure about lost focus!
  //note that if a duplicate is found a hidden form variable is set

  //changed the code to trigger on change - gives a far more immediate effect

  $('#dupradio').hide();
  $('#dupvmes').hide();
  $('#vertext').hide();
  $('#duphidden').hide();
  $('#refreshupload').hide();
  //this only works once the form has focus
  document.onkeypress=function(e){
    var e = window.event || e;
    if (e.keyCode == 27 || e.which == 27){
      parent.dbFM.popUp = true;   //try to fill a variable to prevent a directory fetch
      parent.GB_hide();
    }
  }
  
  var cssObj = {
    backgroundColor: "#ddd",
    color: "rgb(0,40,244)"
  }
  $('#dupradio').css(cssObj);
  $('#dupvmes').css(cssObj);
  
  //we'll try to run something quickly between the time the submit button is pressed and the time the form is redrawn
  $('form :input').click(function() {
    if (this.id == "edit-submit") {
      $('#refreshupload').show();  //show the progress icon and
//      $('#edit-submit').attr("disabled",true); //disable the upload button
//now disabling the upload button works in all the browsers I've tried EXCEPT Safari - where it prevents the upload 'submit' code from 
//ever running - we need to change something else...
        $('#edit-submit').hide();
    }
  });

  $('form :input').change(function() {
    if (this.id == "edit-fname") {
      if (this.value != "") {
        //we need to make an ajax call to the server passing the selected filename. Now MOST browsers send the whole path to the 
        //file (as displayed in the edit box) BUT FF3 send just the filename itself. Need to watch out at the other end
        $.ajax({
          type: "POST",
          url: ajaxUrl(),
          data: "action=fnamechk&fname=" + this.value,
          success: function(msg){
            //check the return values then hide or re-display the choice prompt
            //I THINK we're missing the drupal call??
            var result = Drupal.parseJson(msg);
            if (result.status == false) {
              //hide the prompt for versions / overwrite
              $('#dupradio').hide();
              $('#vertext').hide();
              $('#dupvmes').hide();
              $('#edit-duphidden').val('0');
            }
            else {
              //display the appropriate prompt control
              if (result.data == 'Version found') {
                $('#vertext').show();
                $('#dupvmes').show();
                $('#dupradio').hide();
                $('#edit-duphidden').val('2');
              }
              else {
                $('#vertext').show();
                $('#dupradio').show();
                $('#dupvmes').hide();
                $('#edit-duphidden').val('1');
             }
            }
          }
        });  //end of AJAX call
      }
    }
  });  //end of lostfocus trap
});  //end of ready code
